import 'dotenv/config'

import * as sdk from "matrix-js-sdk";
import axios from 'axios';
import fetch from 'node-fetch';
import { isBefore } from 'date-fns';

let hasAlerted = false;

export type DataPoint = {
  id: string;
  name: string;
  timestamp: string;
  value: number;
};

let tempValue = 0.;

type TeaSenseResult = {
  temperature: number;
};

async function pullTempFromBackend() {
  try {
    hasAlerted = false;
    const response = await fetch(
      process.env.TEASENSE_URL ?? '', {
        signal: AbortSignal.timeout(5000),
      }
    );
    const result = await response.json() as TeaSenseResult;

    if (result?.temperature && result?.temperature >= parseInt(process.env.TEASENSE_TEMP ?? '100.0')) {
      try {
        const content = {
          body: '♨️',
          msgtype: "m.text",
        };

        client.sendEvent(process.env.MATRIX_ROOM_ID ?? '', "m.room.message", content);
        hasAlerted = true;
      } catch (e) {
        console.error(e);
      }
      tempValue = 0.;
    }
  } catch (e) {
    console.error(e);
  } finally {
    setTimeout(() => pullTempFromBackend(), hasAlerted ? 60000 : 5000);
  }
}

const myUserId = process.env.MATRIX_USER;
const myAccessToken = process.env.MATRIX_ACCESS_TOKEN;
const client = sdk.createClient({
    baseUrl: process.env.MATRIX_HOST ?? 'https://matrix.org',
    accessToken: myAccessToken,
    userId: myUserId,
});

(async function () {
  await client.startClient({ initialSyncLimit: 10 });
  await pullTempFromBackend();
})();
